import { ApplicationRef, Injector, RendererFactory2, Type } from '@angular/core';
import { LazyDialogRef, ModuleWithLazyDialog } from '../models';
import * as i0 from "@angular/core";
/**
 * The LazyDialogService responsible for creating lazy loading dialogs.
 *
 * @export
 * @class LazyDialogService
 * @typedef {LazyDialogService}
 */
export declare class LazyDialogService {
    private readonly document;
    private readonly rendererFactory;
    private readonly injector;
    private readonly applicationRef;
    /**
     * Responsible for DOM manipulation.
     *
     * @private
     * @readonly
     * @type {Readonly<Renderer2>}
     */
    private readonly renderer;
    /**
     * Creates an instance of LazyDialogService.
     *
     * @constructor
     * @public
     * @param {Readonly<Document>} document
     * @param {RendererFactory2} rendererFactory
     * @param {Injector} injector
     * @param {ApplicationRef} applicationRef
     */
    constructor(document: Readonly<Document>, rendererFactory: RendererFactory2, injector: Injector, applicationRef: ApplicationRef);
    /**
     * Creates (opens) a lazy loading dialog with provided data.
     *
     * @public
     * @async
     * @template ComponentType
     * @template DataType
     * @param {(Promise<Type<ModuleWithLazyDialog<ComponentType> | ComponentType>>)} module The module containing the lazy dialog component (supports NgModule extending ModuleWithLazyDialog<T> as well as standalone components).
     * @param {?DataType} [data] The data provided to the dialog.
     * @returns {Promise<LazyDialogRef<DataType>>}
     */
    create<ComponentType, DataType>(module: Promise<Type<ModuleWithLazyDialog<ComponentType> | ComponentType>>, data?: DataType): Promise<LazyDialogRef<DataType>>;
    /**
     * Determines the dialog component type (if @param module is a NgModule it also initializes the module).
     *
     * @private
     * @async
     * @template ComponentType
     * @param {(Promise<Type<ModuleWithLazyDialog<ComponentType> | ComponentType>>)} module The module containing the lazy dialog component (supports NgModule extending ModuleWithLazyDialog<T> as well as standalone components).
     * @returns {(Promise<{
        componentType: Type<ComponentType>;
        moduleRef: NgModuleRef<ModuleWithLazyDialog<ComponentType>> | undefined;
      }>)}
     */
    private initModuleAndComponent;
    /**
     * Attaches the dialog to the DOM.
     *
     * @private
     * @template ComponentType
     * @template DataType
     * @param {LazyDialogRef<DataType>} lazyDialogRef The reference of the lazy dialog.
     * @param {ViewContainerRef} dialogContainerVcr The dialog container's view container reference.
     * @param {Type<ComponentType>} componentType The type of the dialog component.
     * @param {(NgModuleRef<ModuleWithLazyDialog<ComponentType>> | undefined)} moduleRef The reference of the module containing the dialog component (only has a value if module isn't a standalone component).
     */
    private initDialog;
    /**
     * Attaches the dialog container to the DOM.
     *
     * @private
     * @async
     * @template ComponentType
     * @template DataType
     * @param {HTMLDivElement} dialogContainerRootElement The HTML element of the dialog container root.
     * @param {(NgModuleRef<ModuleWithLazyDialog<ComponentType>> | undefined)} moduleRef The reference of the module containing the dialog component (only has a value if module isn't a standalone component).
     * @param {?DataType} [data] The data provided to the dialog.
     * @returns {Promise<{
        lazyDialogRef: LazyDialogRef<DataType>;
        dialogContainerVcr: ViewContainerRef;
      }>}
     */
    private initDialogBackgroundOverlay;
    /**
     * Creates the HTML dialog root container element.
     *
     * @private
     * @returns {HTMLDivElement}
     */
    private createDialogRootElement;
    static ɵfac: i0.ɵɵFactoryDeclaration<LazyDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LazyDialogService>;
}
